@@ -1,4 +1,4 @@
-//@line 36 "/mnt/Srcs/F/build/browser/components/safebrowsing/content/sb-loader.js"
+//@line 36 "/home/kojima/Mozilla/build/browser/components/safebrowsing/content/sb-loader.js"
 
 var safebrowsing = {
   appContext: null,
@@ -15,12 +15,29 @@ var safebrowsing = {
   },
 
   setReportPhishingMenu: function() {
+      
+    // A phishing page will have a specific about:blocked content documentURI
+    var isPhishingPage = /^about:blocked\?e=phishingBlocked/.test(content.document.documentURI);
+    
+    // Show/hide the appropriate menu item.
+    document.getElementById("menu_HelpPopup_reportPhishingtoolmenu")
+            .hidden = isPhishingPage;
+    document.getElementById("menu_HelpPopup_reportPhishingErrortoolmenu")
+            .hidden = !isPhishingPage;
+
+    var broadcasterId = isPhishingPage
+                        ? "reportPhishingErrorBroadcaster"
+                        : "reportPhishingBroadcaster";
+
+    var broadcaster = document.getElementById(broadcasterId);
+    if (!broadcaster)
+      return;
+
     var uri = getBrowser().currentURI;
-    var broadcaster = document.getElementById("reportPhishingBroadcaster");
     if (uri && (uri.schemeIs("http") || uri.schemeIs("https")))
       broadcaster.removeAttribute("disabled");
     else
-      broadcaster.disabled = true;
+      broadcaster.setAttribute("disabled", true);
   },
   
   /**
