@@ -134,7 +134,7 @@ pref("gfx.color_management.display_profile", "");
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 138 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 138 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -147,7 +147,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 154 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 154 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -523,7 +523,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 532 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 532 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -752,7 +752,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 766 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 766 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -776,9 +776,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 791 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 791 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 798 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 798 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1112,15 +1112,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1514 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 1515 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 1930 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 1932 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2127 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2129 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2218 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2220 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2221 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2223 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1205,7 +1205,9 @@ pref("font.name.serif.ko", "serif");
 pref("font.name.sans-serif.ko", "sans-serif");
 pref("font.name.monospace.ko", "monospace");
 
-// th
+pref("font.name.serif.th", "serif");
+pref("font.name.sans-serif.th", "sans-serif");
+pref("font.name.monospace.th", "monospace");
 
 pref("font.name.serif.tr", "serif");
 pref("font.name.sans-serif.tr", "sans-serif");
@@ -1269,7 +1271,8 @@ pref("font.size.fixed.ko", 16);
 
 pref("font.default.th", "serif");
 pref("font.size.variable.th", 16);
-pref("font.size.fixed.th", 12);
+pref("font.size.fixed.th", 13);
+pref("font.minimum-size.th", 13);
 
 pref("font.default.tr", "serif");
 pref("font.size.variable.tr", 16);
@@ -1377,15 +1380,15 @@ pref("print.postscript.paper_size",    "letter");
 pref("print.postscript.orientation",   "portrait");
 pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2480 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2485 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2548 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2553 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2574 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2579 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2594 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2599 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
-//@line 2602 "/mnt/Srcs/F/build/modules/libpref/src/init/all.js"
+//@line 2607 "/home/kojima/Mozilla/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
